@@ -47,6 +47,8 @@ def send(func):
             exception_info = str(ex)
             sns.send_dingding(title, title + exception_info, ERROR_GRP_TOKEN)
             # sns.send_dingding(title, title + exception_info, INFO_GRP_TOKEN)
+            logger.info(ex)
+            raise ex
 
     return wrapper
 
